/*  Init
 *
 *  This routine is the initialization task for this test program.
 *  It is called from init_exec and has the responsibility for creating
 *  and starting the tasks that make up the test.  If the time of day
 *  clock is required for the test, it should also be set to a known
 *  value by this function.
 *
 *  Input parameters:  NONE
 *
 *  Output parameters:  NONE
 *
 *  COPYRIGHT (c) 1989-1999.
 *  On-Line Applications Research Corporation (OAR).
 *
 *  The license and distribution terms for this file may be
 *  found in the file LICENSE in this distribution or at
 *  http://www.rtems.com/license/LICENSE.
 *
 *  $Id: init.c,v 1.12.4.1 2003/09/04 18:46:30 joel Exp $
 */

#define CONFIGURE_INIT
#include <system_def.h>
#include "system.h"
#include "app_def.h"
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <errno.h>
#include <stdlib.h>
#include <rtems/error.h>
#include <rtems/monitor.h>
#include <rtems/shell.h>

#include <bsp/mscan.h>
#include <bsp/mscan-base.h>

#include "helpers.h"

#define BUILD_VERSION_STRING(major,minor,patch) \
        __XSTRING(major) "." __XSTRING(minor) "." __XSTRING(patch)

#define RTEMS_VER_CODE VER_CODE(__RTEMS_MAJOR__ ,__RTEMS_MINOR__ ,__RTEMS_REVISION__)


#define CONFIGURE_SHELL_USER_COMMANDS &shell_command_print_can_totals
#define CONFIGURE_SHELL_COMMANDS_INIT
#define CONFIGURE_SHELL_COMMANDS_ALL

#include <rtems/shellconfig.h>
#include <rtems/shell.h>


rtems_task Init(rtems_task_argument ignored){
    rtems_status_code status;
    
    printf( "\n\nRTEMS v "
            BUILD_VERSION_STRING(__RTEMS_MAJOR__ ,__RTEMS_MINOR__ ,__RTEMS_REVISION__)
        "\n");
    
    rtems_monitor_init(RTEMS_MONITOR_SUSPEND|RTEMS_MONITOR_GLOBAL);
    
    printf( "Starting application " SW_VER_ID " v "
            BUILD_VERSION_STRING(SW_VER_MAJOR,SW_VER_MINOR,SW_VER_PATCH)
        "\n" );

    /* Inits */
#ifdef BENCH_BUILD
    start_can(0, NULL);
    start_net(0, NULL);
#ifdef LOAD_BUILD
    start_load(0, NULL);
#endif
#endif

#ifndef BENCH_BUILD        
    rtems_shell_init(
        "SHLL", /* task name */
        RTEMS_MINIMUM_STACK_SIZE * 4, /* task stack size */
        100, /* task priority */
        "/dev/console", /* device name */
        true, /* run forever */
        false, /* wait for shell to terminate */
        NULL /* login check function, use NULL to disable a login check */
    );  
#endif    
    
    status = rtems_task_delete( RTEMS_SELF );
    
    exit( 0 );
}
